mirror of https://lore.kernel.org/lkml/
 help / color / mirror / Atom feed
From: Mike Rapoport <mike.rapoport@gmail.com>
To: Greg Kroah-Hartman <greg@kroah.com>
Cc: Mike Rapoport <mike.rapoport@gmail.com>,
	Sudip Mukherjee <sudipm.mukherjee@gmail.com>,
	Teddy Wang <teddy.wang@siliconmotion.com>,
	Sudip Mukherjee <sudip@vectorindia.org>,
	LKML <linux-kernel@vger.kernel.org>
Subject: [PATCH v3 13/17] staging: sm750fb: ddk750_hwi2c: reduce amount of CamelCase
Date: Sun,  6 Sep 2015 09:18:03 +0300	[thread overview]
Message-ID: <1441520287-5232-14-git-send-email-mike.rapoport@gmail.com> (raw)
In-Reply-To: <1441520287-5232-1-git-send-email-mike.rapoport@gmail.com>

Rename camel case variables deviceAddress, pBuffer and totalBytes to
addr, buf and total_bytes respectively in sm750_hw_i2c_{read,write}_data
functions.

Signed-off-by: Mike Rapoport <mike.rapoport@gmail.com>
---
 drivers/staging/sm750fb/ddk750_hwi2c.c | 36 +++++++++++++++++-----------------
 1 file changed, 18 insertions(+), 18 deletions(-)

diff --git a/drivers/staging/sm750fb/ddk750_hwi2c.c b/drivers/staging/sm750fb/ddk750_hwi2c.c
index abac6ae..8d06f48 100644
--- a/drivers/staging/sm750fb/ddk750_hwi2c.c
+++ b/drivers/staging/sm750fb/ddk750_hwi2c.c
@@ -82,25 +82,25 @@ static long hw_i2c_wait_tx_done(void)
  *  This function writes data to the i2c slave device registers.
  *
  *  Parameters:
  *      deviceAddress   - i2c Slave device address
  *      length          - Total number of bytes to be written to the device
  *      pBuffer         - The buffer that contains the data to be written to the
  *                     i2c device.
  *
  *  Return Value:
  *      Total number of bytes those are actually written.
  */
 static unsigned int hw_i2c_write_data(
-	unsigned char deviceAddress,
+	unsigned char addr,
 	unsigned int length,
-	unsigned char *pBuffer
+	unsigned char *buf
 )
 {
 	unsigned char count, i;
-	unsigned int totalBytes = 0;
+	unsigned int total_bytes = 0;
 
 	/* Set the Device Address */
-	POKE32(I2C_SLAVE_ADDRESS, deviceAddress & ~0x01);
+	POKE32(I2C_SLAVE_ADDRESS, addr & ~0x01);
 
 	/* Write data.
 	 * Note:
@@ -119,7 +119,7 @@ static unsigned int hw_i2c_write_data(
 
 		/* Move the data to the I2C data register */
 		for (i = 0; i <= count; i++)
-			POKE32(I2C_DATA0 + i, *pBuffer++);
+			POKE32(I2C_DATA0 + i, *buf++);
 
 		/* Start the I2C */
 		POKE32(I2C_CTRL, FIELD_SET(PEEK32(I2C_CTRL), I2C_CTRL, CTRL, START));
@@ -132,11 +132,11 @@ static unsigned int hw_i2c_write_data(
 		length -= (count + 1);
 
 		/* Total byte written */
-		totalBytes += (count + 1);
+		total_bytes += (count + 1);
 
 	} while (length > 0);
 
-	return totalBytes;
+	return total_bytes;
 }
 
 
@@ -147,9 +147,9 @@ static unsigned int hw_i2c_write_data(
  *  in the given buffer
  *
  *  Parameters:
  *      deviceAddress   - i2c Slave device address
  *      length          - Total number of bytes to be read
  *      pBuffer         - Pointer to a buffer to be filled with the data read
  *                     from the slave device. It has to be the same size as the
  *                     length to make sure that it can keep all the data read.
  *
@@ -157,16 +157,16 @@ static unsigned int hw_i2c_write_data(
  *      Total number of actual bytes read from the slave device
  */
 static unsigned int hw_i2c_read_data(
-	unsigned char deviceAddress,
+	unsigned char addr,
 	unsigned int length,
-	unsigned char *pBuffer
+	unsigned char *buf
 )
 {
 	unsigned char count, i;
-	unsigned int totalBytes = 0;
+	unsigned int total_bytes = 0;
 
 	/* Set the Device Address */
-	POKE32(I2C_SLAVE_ADDRESS, deviceAddress | 0x01);
+	POKE32(I2C_SLAVE_ADDRESS, addr | 0x01);
 
 	/* Read data and save them to the buffer.
 	 * Note:
@@ -192,17 +192,17 @@ static unsigned int hw_i2c_read_data(
 
 		/* Save the data to the given buffer */
 		for (i = 0; i <= count; i++)
-			*pBuffer++ = PEEK32(I2C_DATA0 + i);
+			*buf++ = PEEK32(I2C_DATA0 + i);
 
 		/* Substract length by 16 */
 		length -= (count + 1);
 
 		/* Number of bytes read. */
-		totalBytes += (count + 1);
+		total_bytes += (count + 1);
 
 	} while (length > 0);
 
-	return totalBytes;
+	return total_bytes;
 }
 
 
@@ -82,25 +82,25 @@ static long hw_i2c_wait_tx_done(void)
  *
  *  Parameters:
- *      deviceAddress   - i2c Slave device address
+ *      addr            - i2c Slave device address
  *      length          - Total number of bytes to be written to the device
@@ -82,25 +82,25 @@ static long hw_i2c_wait_tx_done(void)
  *      length          - Total number of bytes to be written to the device
- *      pBuffer         - The buffer that contains the data to be written to the
+ *      buf             - The buffer that contains the data to be written to the
  *                     i2c device.
  *
@@ -147,9 +147,9 @@ static unsigned int hw_i2c_write_data(
  *
  *  Parameters:
- *      deviceAddress   - i2c Slave device address
+ *      addr            - i2c Slave device address
  *      length          - Total number of bytes to be read
@@ -147,9 +147,9 @@ static unsigned int hw_i2c_write_data(
  *      length          - Total number of bytes to be read
- *      pBuffer         - Pointer to a buffer to be filled with the data read
+ *      buf             - Pointer to a buffer to be filled with the data read
  *                     from the slave device. It has to be the same size as the
  *                     length to make sure that it can keep all the data read.
-- 
2.1.0


  parent reply	other threads:[~2015-09-06  6:22 UTC|newest]

Thread overview: 28+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2015-09-06  6:17 [PATCH v3 00/17] staging: sm750fb: coding style fixes Mike Rapoport
2015-09-06  6:17 ` [PATCH v3 01/17] staging: sm750fb: rename hwI2CInit to sm750_hw_i2c_init Mike Rapoport
2015-09-09 18:39   ` Greg Kroah-Hartman
2015-09-06  6:17 ` [PATCH v3 02/17] staging: sm750fb: rename hwI2CClose to sm750_hw_i2c_close Mike Rapoport
2015-09-09 18:40   ` Greg Kroah-Hartman
2015-09-06  6:17 ` [PATCH v3 03/17] staging: sm750fb: rename hwI2CReadReg to sm750_hw_i2c_read_reg Mike Rapoport
2015-09-09 18:40   ` Greg Kroah-Hartman
2015-09-06  6:17 ` [PATCH v3 04/17] staging: sm750fb: rename hwI2CWriteReg to sm750_hw_i2c_write_reg Mike Rapoport
2015-09-06  6:17 ` [PATCH v3 05/17] staging: sm750fb: ddk750_hwi2c: rename CamelCase static functions Mike Rapoport
2015-09-06  6:17 ` [PATCH v3 06/17] staging: sm750fb: rename swI2CInit to sm750_sw_i2c_init Mike Rapoport
2015-09-09 18:41   ` Greg Kroah-Hartman
2015-09-09 20:03     ` Mike Rapoport
2015-09-09 20:07       ` Greg Kroah-Hartman
2015-09-10  4:40         ` Sudip Mukherjee
2015-09-10 12:39           ` Mike Rapoport
2015-09-10 13:01             ` Sudip Mukherjee
2015-09-12  2:51               ` Greg Kroah-Hartman
2015-09-06  6:17 ` [PATCH v3 07/17] staging: sm750fb: rename swI2CReadReg to sm750_sw_i2c_read_reg Mike Rapoport
2015-09-06  6:17 ` [PATCH v3 08/17] staging: sm750fb: rename swI2CWriteReg to sm750_sw_i2c_write_reg Mike Rapoport
2015-09-06  6:17 ` [PATCH v3 09/17] staging: sm750fb: ddk750_swi2c: staticize swI2C{SCL,SDA} Mike Rapoport
2015-09-06  6:18 ` [PATCH v3 10/17] staging: sm750fb: ddk750_swi2c: rename CamelCase static functions Mike Rapoport
2015-09-06  6:18 ` [PATCH v3 11/17] staging: sm750fb: ddk750_hw_i2c: rename busSpeedMode Mike Rapoport
2015-09-06  6:18 ` [PATCH v3 12/17] staging: sm750fb: hw_i2c_{read,write}: rename CamelCase variables Mike Rapoport
2015-09-06  6:18 ` Mike Rapoport [this message]
2015-09-06  6:18 ` [PATCH v3 14/17] staging: sm750fb: ddk750_swi2c: rename CamelCase static variables Mike Rapoport
2015-09-06  6:18 ` [PATCH v3 15/17] staging: sm750fb: ddk750_swi2c: further reduce CamelCase Mike Rapoport
2015-09-06  6:18 ` [PATCH v3 16/17] staging: sm750fb: ddk750_*i2c: remove multiple blank lines Mike Rapoport
2015-09-06  6:18 ` [PATCH v3 17/17] staging: sm750fb: ddk750_*i2c: shorten lines to under 80 characters Mike Rapoport

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=1441520287-5232-14-git-send-email-mike.rapoport@gmail.com \
    --to=mike.rapoport@gmail.com \
    --cc=greg@kroah.com \
    --cc=linux-kernel@vger.kernel.org \
    --cc=sudip@vectorindia.org \
    --cc=sudipm.mukherjee@gmail.com \
    --cc=teddy.wang@siliconmotion.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox

Powered by JetHome